@@ -2,7 +2,7 @@ package Module::Build::Pluggable::XSUtil;
 use strict;
 use warnings;
 use 5.008005;
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 use parent qw/Module::Build::Pluggable::Base/;
 use Config;
 use Carp ();
@@ -75,7 +75,7 @@ sub HOOK_configure {
 
         require ExtUtils::CBuilder;
         my $cbuilder = ExtUtils::CBuilder->new(quiet => 1);
-        $cbuilder->have_cpluplus or do {
+        $cbuilder->have_cplusplus or do {
             warn "This environment does not have a C++ compiler(OS unsupported)\n";
             exit 0;
         };
